from setuptools import setup

setup(name='onlinekx',
      version='0.1',
      description='The onlinekx joke in the world',
      url='http://www.baidu.com',
      author='ben',
      author_email='ben@example.com',
      license='MIT',
      packages=['onlinekx'],
      zip_safe=False)